==> 0.0.50.tar.gz: example/lib/Screen/OtpScreen.dart <==
import 'package:bui_component/OtpScreenComponent.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:flutter/material.dart';

import 'DashBoardScreen.dart';
import 'package:toast/toast.dart';

import 'package:shared_preferences/shared_preferences.dart';

class OtpScreen extends StatefulWidget {
  @override
  _OtpScreenState createState() => _OtpScreenState();
}

class _OtpScreenState extends State<OtpScreen> {
  var _formKey = GlobalKey<FormState>();
  String otpValue;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    //_onCountryChange(code);
    getStringValuesSF();
  }

  Color theme = AppColors.APP_COLOR_PRIMARY;
  SharedPreferences prefs;

  getStringValuesSF() async {
    prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: OtpScreenComponent(
        globalKey: _formKey,
        otpSuccess: signInPage,
        onBackPress: onBackPress,
        backgroundColor: theme,
        buttonColor: AppColors.APP_COLOR_PRIMARY,
        title: AppStrings.APP_NAME,
        validateCondition: validationCondition,
      ),
    );
  }

  void onBackPress() {
    Navigator.pop(context);
  }

  Future<void> signInPage() async {
    final isValid = _formKey.currentState.validate();
    if (!isValid) {
      return;
    }
    _formKey.currentState.save();

    if (otpValue == "999999") {
      Toast.show("Login Succeed", context,
          duration: Toast.LENGTH_SHORT, gravity: Toast.BOTTOM);

      Navigator.pushReplacement(
          context,
          MaterialPageRoute(
              builder: (BuildContext context) => DashBoardScreen()));
    } else {
      Toast.show(AppStrings.INVALID_OTP, context,
          duration: Toast.LENGTH_SHORT, gravity: Toast.BOTTOM);
    }
  }

  Future<dynamic> validationCondition(String val) async {
    setState(() {
      otpValue = val;
    });
  }
}

==> 0.0.54.tar.gz: example/lib/Screen/OtpScreen.dart <==
import 'package:bui_component/OtpScreenComponent.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:flutter/material.dart';

import 'MenuScreen.dart';
import 'package:toast/toast.dart';

import 'package:shared_preferences/shared_preferences.dart';

class OtpScreen extends StatefulWidget {
  @override
  _OtpScreenState createState() => _OtpScreenState();
}

class _OtpScreenState extends State<OtpScreen> {
  var _formKey = GlobalKey<FormState>();
  String otpValue;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    //_onCountryChange(code);
    getStringValuesSF();
  }

  Color theme = AppColors.APP_COLOR_PRIMARY;
  SharedPreferences prefs;

  getStringValuesSF() async {
    prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: OtpScreenComponent(
        globalKey: _formKey,
        otpSuccess: signInPage,
        onBackPress: onBackPress,
        backgroundColor: theme,
        buttonColor: AppColors.APP_COLOR_PRIMARY,
        title: AppStrings.APP_NAME,
        validateCondition: validationCondition,
      ),
    );
  }

  void onBackPress() {
    Navigator.pop(context);
  }

  Future<void> signInPage() async {
    final isValid = _formKey.currentState.validate();
    if (!isValid) {
      return;
    }
    _formKey.currentState.save();

    if (otpValue == "999999") {
      Toast.show("Login Succeed", context,
          duration: Toast.LENGTH_SHORT, gravity: Toast.BOTTOM);

      Navigator.pushReplacement(
          context,
          MaterialPageRoute(
              builder: (BuildContext context) => MenuScreen()));
    } else {
      Toast.show(AppStrings.INVALID_OTP, context,
          duration: Toast.LENGTH_SHORT, gravity: Toast.BOTTOM);
    }
  }

  Future<dynamic> validationCondition(String val) async {
    setState(() {
      otpValue = val;
    });
  }
}
